@@ -8,9 +8,9 @@ from plone import api
 from plone.api.content import _parse_object_provides_query
 from plone.api.tests.base import INTEGRATION_TESTING
 from plone.app.contenttypes.interfaces import IFolder
-from plone.app.layout.navigation.interfaces import INavigationRoot
 from plone.app.linkintegrity.exceptions import LinkIntegrityNotificationException
 from plone.app.textfield import RichTextValue
+from plone.base.interfaces import INavigationRoot
 from plone.indexer import indexer
 from plone.uuid.interfaces import IMutableUUID
 from plone.uuid.interfaces import IUUIDGenerator
@@ -192,7 +192,7 @@ class TestPloneApiContent(unittest.TestCase):
             folder.setConstrainTypesMode(ENABLED)
             folder.setLocallyAllowedTypes(("News Item",))
         else:  # DX
-            from Products.CMFPlone.interfaces import ISelectableConstrainTypes
+            from plone.base.interfaces import ISelectableConstrainTypes
 
             constraints = ISelectableConstrainTypes(folder)
             constraints.setConstrainTypesMode(ENABLED)
@@ -478,6 +478,16 @@ class TestPloneApiContent(unittest.TestCase):
         # title is an attribute
         self.assertIsNone(api.content.get("/about/team/title"))
 
+    def test_get_of_content_in_inaccessible_container(self):
+        """Test getting items in a inaccessible container.
+        Worked in Plone 5.1 but raised Unauthorized since 5.2."""
+        api.content.transition(obj=self.team, transition="publish")
+        with api.env.adopt_roles(["Member"]):
+            team_by_path = api.content.get("/about/team")
+            self.assertEqual(self.team, team_by_path)
+            team_by_uid = api.content.get(UID=self.team.UID())
+            self.assertEqual(self.team, team_by_uid)
+
     def test_move_constraints(self):
         """Test the constraints for moving content."""
         from plone.api.exc import MissingParameterError
@@ -1437,3 +1447,66 @@ class TestPloneApiContent(unittest.TestCase):
 
         for should_be_there in should_be_theres:
             self.assertIn((should_be_there + "\n"), str(cm.exception))
+
+    def test_get_path_absolute(self):
+        """Test getting the path of a content object with relative parameter set to False."""
+        from plone.api.exc import InvalidParameterError
+
+        portal = self.layer["portal"]
+
+        # Test portal root
+        self.assertEqual(
+            api.content.get_path(portal), "/plone"  # This assumes default Plone site id
+        )
+
+        # Test folder structure
+        folder = api.content.create(container=portal, type="Folder", id="test-folder")
+        self.assertEqual(api.content.get_path(folder), "/plone/test-folder")
+
+        # Test nested content
+        document = api.content.create(
+            container=folder, type="Document", id="test-document"
+        )
+        self.assertEqual(
+            api.content.get_path(document), "/plone/test-folder/test-document"
+        )
+
+        # Test invalid object
+        invalid_obj = object()
+        with self.assertRaises(InvalidParameterError):
+            api.content.get_path(invalid_obj)
+        self.assertRaisesRegex(
+            InvalidParameterError,
+            r"^Cannot get path of object <object object at 0x[0-9a-f]+>$",
+        )
+
+    def test_get_path_relative(self):
+        from plone.api.exc import InvalidParameterError
+
+        portal = self.layer["portal"]
+
+        # Test portal root
+        self.assertEqual(api.content.get_path(portal, relative=True), "")
+
+        # Test folder structure
+        folder = api.content.create(container=portal, type="Folder", id="test-folder")
+        self.assertEqual(api.content.get_path(folder, relative=True), "test-folder")
+
+        # Test nested content
+        document = api.content.create(
+            container=folder, type="Document", id="test-document"
+        )
+        self.assertEqual(
+            api.content.get_path(document, relative=True),
+            "test-folder/test-document",
+        )
+
+        # Test object outside portal
+        class FauxObject:
+            def getPhysicalPath(self):
+                return ("", "foo", "bar")
+
+        outside_obj = FauxObject()
+        with self.assertRaises(InvalidParameterError) as cm:
+            api.content.get_path(outside_obj, relative=True)
+        self.assertIn("Object not in portal path", str(cm.exception))
